Class: DSN::Subcode::DetailSubcode
- Defined in:
- lib/dsn/subcode/detail_subcode.rb
Overview
The detail value provides more information about the status and is defined relative to the subject of the status.
Method Summary
Methods inherited from Base
#initialize, #to_i, #to_s, #valid?
Constructor Details
This class inherits a constructor from DSN::Subcode::Base